# Berzelius Training

## How to Create a New Lesson Based on the Template

This guide explains how to create a new training lesson using the existing `sphinx-lesson-template`.

---

### Step 1: Copy the Template Folder

From the root of the repository:

```bash
cp -r sphinx-lesson-template getting-started-with-berzelius
```

This creates a new folder for your lesson:

```bash
berzelius-training/
├── sphinx-lesson-template/
└── getting-started-with-berzelius/
```

### Step 2: Update `getting-started-with-berzelius/content/conf.py`:

```python
project = "Getting Started with Berzelius"
author = "Berzelius Training Team"
```

Update index.md and other files in `content/` to reflect the new lesson topic and structure.

### Step 3: Update the Landing Page `landing/content/index.md`

```md
:caption: Training
:maxdepth: 1

getting-started-with-berzelius/index
```

### Step 4: Test Locally

Create an testing environment:
```bash
mamba create -n sphinx-env python=3.11
mamba activate sphinx-env
cd sphinx-lesson-template
pip install -r requirements.txt
```

Test the new lesson:
```bash
cd getting-started-with-berzelius
make dirhtml
open _build/dirhtml/index.html
```

Test all lessons:
```bash
# From the berzelius-training root directory
bash build_pages.sh
```

Run the server from the landing page"
```bash
python3 -m http.server 8000 --directory landing/_build/dirhtml
```

Open your browser at:
```bash
http://localhost:8000
```

If everything looks OK, remove the built files before push
```bash
bash build_clean.sh
```

### Step 5: Update `.gitlab-ci.yml`

The pipeline will automatically find all lessons (folders) and build them.

### Step 6: Commit and Push the New Lesson

```bash
git add getting-started-with-berzelius .gitlab-ci.yml
git commit -m "Add new lesson: Getting Started with Berzelius"
git push
```

This will build your new lesson and place it in:

```
https://nsc.gitlab-pages.liu.se/berzelius-training/getting-started-with-berzelius/
```