# Getting Started Quickly

Berzelius is designed to help you get started with minimal setup. You can either use pre-installed software modules or build your own environment depending on your needs.

---

## 1. Software Environment Options

You can choose to:

- Use pre-installed modules, such as:
  - AlphaFold
  - Miniforge3
  - VS Code
  - etc.

- Build your own environment:
  - Using Conda environments
  - Building containers
  - Compiling from source
  - etc.

Graphical applications can be launched via ThinLinc, and SLURM is used to manage computing resources and schedule jobs.

## 2. Run Your First Job on Berzelius

This streamlined setup helps new users explore Berzelius quickly and efficiently.

1. Connect to Berzelius (via SSH or ThinLinc)
```
ssh <your username>@berzelius.nsc.liu
```
2. Load modules for the tools you need
```
# Load the Miniforge3 Module
module load Miniforge3/24.7.1-2-hpc1-bdist

# Create a New Mamba Environment
mamba create --name pytorch-2.6.0-python-3.10 python=3.10

# Activate the Environment
mamba activate pytorch-2.6.0-python-3.10

# Install PyTorch 2.6.0 and Related Packages
mamba install pytorch==2.6.0 torchvision torchaudio pytorch-cuda=12.1 -c pytorch -c nvidia
```
3. Request a GPU and run your job
```
# Clone an Example Repo
git clone https://github.com/pytorch/examples

# Start an Interactive Job With 1 GPU for 30 Minutes
interactive --gpus 1 -t 30 -A <your-project-account> --reservation=devel

# Activate the Environment on the Compute Node
mamba activate pytorch-2.6.0-python-3.10

# Run an Example Training Script
python examples/mnist/main.py --epochs 10
```

4. Monitor the GPU usage

You can monitor GPU usage and performance metrics for your job using the `jobgraph` command. It gives you a visual summary of GPU utilization, power consumption, memory use, and more — useful for checking if your resources are well-utilized or if your job is underperforming.

```
jobgraph -j <jobid>
```

:::{figure} img/jobgraph_overview.png
:alt: jobgraph example
:width: 800px
:align: center
:name: fig-berzelius

Monitor GPU usage using the command jobgraph
:::

