# Concepts

Before diving into best practices, it's important to understand the key tools and terminology related to the Conda ecosystem. Below, we categorize the most commonly used tools into Package Managers and Distributions, followed by a summary comparison.

---

## 1. Package Managers

These tools handle environment creation, dependency resolution, and package installation.

### 1.1 Conda

A widely used open-source package and environment manager. It installs packages and manages isolated environments for Python and other languages.

### 1.2 Mamba

A fast, drop-in replacement for Conda. Written in C++, it significantly speeds up dependency resolution and is highly recommended on HPC systems.

## 2. Distributions

These are installers or bundles that include the package manager (Conda or Mamba), pre-installed packages, and configuration defaults.

### 2.1 Anaconda

A full-featured Conda distribution that includes hundreds of pre-installed data science packages. Convenient for local use but not ideal for HPC due to its size.

Anaconda is also the name of the company — Anaconda, Inc. — that develops and maintains this distribution, along with tools like Anaconda Navigator and Anaconda Cloud.


### 2.2 Miniconda

A minimal Conda distribution containing only Conda and Python. Lightweight and customizable — good for controlled environments.


### 2.3 Mambaforge

A now-deprecated variant of Miniforge that previously came with `mamba` pre-installed and used `conda-forge` as the default channel. 

**Note**: As of July 2024, `Mambaforge` is deprecated. The `conda-forge` community now recommends using `Miniforge` and installing `mamba` into your environment or base environment as needed. This allows more flexibility and avoids maintaining a separate installer for each combination.


### 2.4 Miniforge

A minimal Conda distribution similar to Miniconda, but preconfigured to use the `conda-forge` community channel by default. It now includes both `conda` and `mamba` in the base environment. Miniforge is ideal for reproducible, open-source environments and is well-suited for HPC systems.


## 3. Channels

In the Conda ecosystem, channels are the locations where packages are stored and downloaded from. When you create or update an environment, Conda uses channels to look up package versions and resolve dependencies.

### 3.1 Default Channel of Anaconda and Miniconda

If you're using Anaconda or Miniconda, the default channel is maintained by Anaconda, Inc. It includes stable and widely used packages, but updates may be slower and some packages may lag behind community-driven sources.

**Note**: Since April 2020, use of the `anaconda` (defaults) channel is governed by the [Anaconda Terms of Service](https://www.anaconda.com/terms-of-service). These terms place restrictions on commercial use, especially in large organizations (defined as having 200 or more employees).

If you're working in an academic or non-commercial context, you're generally safe. However, for public HPC systems or institutional projects, it's best practice to use `conda-forge` instead, which is open-source and has no such licensing limitations.


### 3.2 Default Channel of Mambaforge and Miniforge

conda-forge is a community-maintained channel that provides a vast and up-to-date collection of open-source packages. It is the default for Miniforge and Mambaforge.

Benefits of using `conda-forge`:
- More packages, including cutting-edge tools
- Faster updates
- Transparent, automated build system
- Better support for cross-platform and HPC environments