# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = "Managing Conda Environments: Best Practices"
copyright = "2025, the contributors"
author = "Berzelius Training Team"

# These GitHub-related variables are only used in the "Edit on GitHub" links.
# If you're hosting on GitLab or not using GitHub, disable that feature.
html_context = {
    "display_github": False  # disables Edit on GitHub button
}

# -- General configuration ---------------------------------------------------

extensions = [
    "sphinx_lesson",                         # ENCCS-specific lesson theme
    "sphinx.ext.todo",                       # Enables TODO notes
    "sphinx_rtd_theme_ext_color_contrast",   # Contrast fix for accessibility
]

nb_execution_mode = "cache"

myst_enable_extensions = [
    "colon_fence",
]

copybutton_exclude = ".linenos, .gp"

exclude_patterns = [
    "README*",
    "_build",
    "Thumbs.db",
    ".DS_Store",
    "jupyter_execute",
    "*venv*",
]

# -- Options for HTML output -------------------------------------------------

html_theme = "sphinx_rtd_theme"
html_logo = "img/nsc_logo.png"
html_favicon = "img/favicon.ico"

html_static_path = ['_static']
html_css_files = ["overrides.css"]

# -- Custom lesson directives ------------------------------------------------

from sphinx_lesson.directives import _BaseCRDirective


class SignatureDirective(_BaseCRDirective):
    extra_classes = ["toggle-shown", "dropdown"]


class ParametersDirective(_BaseCRDirective):
    extra_classes = ["dropdown"]


class TypealongDirective(_BaseCRDirective):
    extra_classes = ["toggle-shown", "dropdown"]


DIRECTIVES = [SignatureDirective, ParametersDirective, TypealongDirective]


def setup(app):
    for obj in DIRECTIVES:
        app.add_directive(obj.cssname(), obj)
