# Managing Conda Environments: Best Practices

Managing Conda environments effectively is key to ensuring reproducibility, compatibility, and efficient resource use — especially on high-performance computing (HPC) systems like Berzelius. This guide outlines recommended practices for creating, maintaining, and sharing Conda environments for scientific workflows, machine learning, and data analysis.

It covers environment creation, version pinning, environment sharing, and useful tips to avoid common pitfalls when working with `conda` or `mamba`.

:::{prereq}
- Basic familiarity with the Linux command line
- Some basic understanding of Python (e.g., installing packages, running scripts)
- `mamba` or `conda` installed locally (we recommend `mamba` on Berzelius for faster operations)
- Optional: An active project on Berzelius, if you plan to follow along on the system 
:::


<!-- ```{csv-table}
:delim: ;
:widths: auto

20 min ; {doc}`filename`
``` -->

```{toctree}
:caption: The lesson
:maxdepth: 1

1. concepts
2. best-practices
```

```{toctree}
:caption: Reference
:maxdepth: 1

quick-reference
<!-- guide -->
```

(learner-personas)=

## Who Is the Course For?

This course is intended for researchers, engineers, and students who use Conda or Mamba to manage software environments on HPC systems such as Berzelius. It is especially valuable for users working in data science, machine learning, or scientific computing, where reproducibility and environment isolation are critical.

Whether you're just getting started with Conda or looking to improve your workflow with best practices, this guide will help you create efficient, reliable, and portable environments tailored to your projects.

## About the Course

This course provides practical guidance on managing Conda environments effectively in high-performance computing (HPC) settings, with a focus on best practices for Berzelius users. You'll learn how to create clean and reproducible environments using `mamba`, control package versions, share environments with collaborators, and avoid common pitfalls such as bloated or broken setups.

The course combines hands-on examples with clear explanations, aiming to help you:

- Understand the structure and purpose of Conda environments
- Choose between `conda`, `mamba`, and `Miniforge`
- Create minimal, portable environments for research workflows
- Safely update, freeze, and export environments
- Use Conda effectively on shared systems like Berzelius

By the end of the course, you'll be better equipped to manage your Python environments in a way that improves both productivity and reproducibility.

<!-- ## See also

## Credits -->

```{toctree}
:caption: Berzelius Training Hub
:maxdepth: 1
:hidden:

go-to-landing
```