#!/bin/bash
set -e

echo "=== Finding lessons ==="

landing_content_dir="landing/content"

# Automatically find all top-level directories that contain a 'content' folder
lesson_names=()
for dir in */; do
    if [ -d "${dir}content" ] && [ "$dir" != "landing/" ]; then
        lesson_names+=("${dir%/}")
    fi
done

echo "Found lessons: ${lesson_names[*]}"

### Step 1: Copy lesson content into landing/content ###
echo "=== Copying lesson content into landing/content ==="

for lesson in "${lesson_names[@]}"
do
    src_dir="${lesson}/content"
    dst_dir="${landing_content_dir}/${lesson}"

    echo "Copying: $src_dir -> $dst_dir"

    if [ -e "$dst_dir" ]; then
        echo "Removing existing directory: $dst_dir"
        rm -rf "$dst_dir"
    fi

    mkdir -p "$dst_dir"
    cp -r "$src_dir/"* "$dst_dir/"
done

### Step 2: Build each lesson ###
echo "=== Building lessons ==="

for lesson in "${lesson_names[@]}" "landing"
do
    echo "Building: $lesson"
    (cd "$lesson" && make dirhtml)
done

### Step 3: Copy built HTMLs into landing/_build/dirhtml ###
echo "=== Copying built lessons into landing/_build/dirhtml ==="

target_dir="landing/_build/dirhtml"
mkdir -p "$target_dir"

for lesson in "${lesson_names[@]}"
do
    src_dir="${lesson}/_build/dirhtml"
    dst_dir="${target_dir}/${lesson}"

    echo "Copying ${lesson} into landing directory"
    rm -rf "$dst_dir"
    cp -r "$src_dir" "$dst_dir"
done

echo "✅ All lessons built and copied successfully."
